==> nana-1.08.tar.gz: nana-1.08/test/DL.c <==
/*
 * DL.c -  check out DL.h
 *
 * Copyright (c) 1997 Phil Maker
 * All rights reserved.
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions
 * are met:
 * 1. Redistributions of source code must retain the above copyright
 *    notice, this list of conditions and the following disclaimer.
 * 2. Redistributions in binary form must reproduce the above copyright
 *    notice, this list of conditions and the following disclaimer in the
 *    documentation and/or other materials provided with the distribution.
 *
 * THIS SOFTWARE IS PROVIDED BY THE AUTHOR AND CONTRIBUTORS ``AS IS'' AND
 * ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE
 * IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE
 * ARE DISCLAIMED.  IN NO EVENT SHALL THE AUTHOR OR CONTRIBUTORS BE LIABLE
 * FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL
 * DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS
 * OR SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION)
 * HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT
 * LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY
 * OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF
 * SUCH DAMAGE.
 *
 * $Id: DL.c,v 1.2 1997/05/04 14:37:40 pjm Exp $
 */


#include <stdio.h>
#include "check.h"

#define DL_DEFAULT_HANDLER(g,h,p,f...) \
@@call printf(f)@@

#define DL_DEFAULT_GUARD DL_enabled

#include "../src/DL.h"

int DL_enabled = 1;

int main() {

     CHECKMESSAGE("DL.h: basic tests");
     
     CHECKANSWER(DL("hello"),hello);
     CHECKANSWER(DL("hello %d", 9+1),hello 10);
     CHECKANSWER(DL("hello %d %s",9+1,"x"),hello 10 x);
     CHECKANSWER(DL("hello %d\t%s",9+1,"x"),hello 10\tx);
     
     DL_enabled = 0;
     CHECKEMPTY(DL("hello"));
     CHECKEMPTY(DL("hello %d", 9+1));

     return 0;
     
}

==> nana-1.11.tar.gz: nana-1.11/test/DL.c <==
/*
 * DL.c -  check out DL.h
 *
 * Copyright (c) 1997 Phil Maker
 * All rights reserved.
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions
 * are met:
 * 1. Redistributions of source code must retain the above copyright
 *    notice, this list of conditions and the following disclaimer.
 * 2. Redistributions in binary form must reproduce the above copyright
 *    notice, this list of conditions and the following disclaimer in the
 *    documentation and/or other materials provided with the distribution.
 *
 * THIS SOFTWARE IS PROVIDED BY THE AUTHOR AND CONTRIBUTORS ``AS IS'' AND
 * ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE
 * IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE
 * ARE DISCLAIMED.  IN NO EVENT SHALL THE AUTHOR OR CONTRIBUTORS BE LIABLE
 * FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL
 * DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS
 * OR SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION)
 * HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT
 * LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY
 * OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF
 * SUCH DAMAGE.
 *
 * $Id: DL.c,v 1.3 1997/11/12 06:17:03 pjm Exp $
 */


#include <stdio.h>
#include "check.h"

#define DL_DEFAULT_HANDLER(g,h,p,f...) \
@@call printf(f)@@

#define DL_DEFAULT_GUARD DL_enabled

#include "../src/DL.h"

int DL_enabled = 1;

int main() {

     CHECKMESSAGE("DL.h: basic tests");
     
     CHECKANSWER(DL("hello"),hello);
     CHECKANSWER(DL("hello %d", 9+1),hello 10);
     CHECKANSWER(DL("hello %d %s",9+1,"x"),hello 10 x);
     CHECKANSWER(DL("hello %d\t%s",9+1,"x"),hello 10\tx);
     CHECKANSWER(DL("%s hello %d\t%s", "hello ", 9+1,"x"),hello hello 10\tx);
     CHECKANSWER(DL("%s hello %2.1f\t%s", "hello ", 3.0 + 0.1,"x"),hello hello 3.1\tx);
     
     DL_enabled = 0;
     CHECKEMPTY(DL("hello"));
     CHECKEMPTY(DL("hello %d", 9+1));

     return 0;
     
}
